<?php
/**
 * @file
 * This file contains redirect related functions for openlucius.
 */

/**
 * Global redirect function for redirecting to specific pages and tabs.
 *
 * @param string $path
 *   The path to redirect to.
 * @param null $tab
 *   The tab to open if needed.
 */
function openlucius_core_custom_path_redirect($path, $tab = NULL) {

  global $user;

  // Initialize location.
  $location = '';

  // Check path.
  if (!empty($path)) {

    // Dashboard path.
    if ($path == 'dashboard') {

      // Location based on global user.
      $location = 'user/dashboard/' . $user->uid;
    }
    else if ($path == 'calendar') {

      // Location based on global user.
      $location = 'user-calendar/month';
    }
  }

  // Check location.
  if (!empty($location)) {

    // Check tab.
    if (empty($tab)) {

      // Redirect to user dashboard without tab.
      drupal_goto($location);
    }
    else {
      // Redirect to user dashboard with active tab.
      drupal_goto($location, array(
        'query' => array(
          'tab' => $tab,
        )
      ));
    }
  }

  // Exit if no location.
  drupal_exit();
}
